==> backend-naive-0.1.0-20170829.132944-4.jar: public/js/out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.math.Integer', 'goog.string.StringBuffer', 'goog.array', 'goog.math.Long']);
goog.addDependency("../orcl/utils/hashify.js", ['orcl.utils.hashify'], ['cljs.core']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../orcl/utils.js", ['orcl.utils'], ['orcl.utils.hashify', 'cljs.core', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/impl/utils.js", ['cljs.tools.reader.impl.utils'], ['goog.string', 'cljs.core', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/reader_types.js", ['cljs.tools.reader.reader_types'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/tools/reader/impl/inspect.js", ['cljs.tools.reader.impl.inspect'], ['cljs.core']);
goog.addDependency("../cljs/tools/reader/impl/errors.js", ['cljs.tools.reader.impl.errors'], ['cljs.core', 'cljs.tools.reader.reader_types', 'cljs.tools.reader.impl.inspect', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/impl/commons.js", ['cljs.tools.reader.impl.commons'], ['cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/tools/reader.js", ['cljs.tools.reader'], ['cljs.tools.reader.impl.commons', 'goog.string', 'cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils', 'goog.array']);
goog.addDependency("../cljs/env.js", ['cljs.env'], ['cljs.core']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../cljs/tools/reader/edn.js", ['cljs.tools.reader.edn'], ['cljs.tools.reader.impl.commons', 'cljs.tools.reader', 'goog.string', 'cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['cljs.tools.reader.edn', 'cljs.tools.reader', 'cljs.core', 'goog.object', 'goog.string.StringBuffer']);
goog.addDependency("../cljs/tagged_literals.js", ['cljs.tagged_literals'], ['cljs.core', 'cljs.reader']);
goog.addDependency("../cljs/analyzer.js", ['cljs.analyzer'], ['cljs.tools.reader', 'goog.string', 'cljs.core', 'cljs.tools.reader.reader_types', 'cljs.env', 'clojure.set', 'cljs.tagged_literals', 'clojure.string', 'cljs.reader']);
goog.addDependency("../cljs/source_map/base64.js", ['cljs.source_map.base64'], ['cljs.core']);
goog.addDependency("../cljs/source_map/base64_vlq.js", ['cljs.source_map.base64_vlq'], ['cljs.source_map.base64', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../cljs/source_map.js", ['cljs.source_map'], ['cljs.source_map.base64_vlq', 'cljs.core', 'goog.object', 'clojure.set', 'clojure.string']);
goog.addDependency("../cljs/compiler.js", ['cljs.compiler'], ['cljs.tools.reader', 'goog.string', 'cljs.core', 'cljs.env', 'goog.string.StringBuffer', 'clojure.set', 'cljs.analyzer', 'cljs.source_map', 'clojure.string']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../cljs/spec/gen/alpha.js", ['cljs.spec.gen.alpha'], ['cljs.core']);
goog.addDependency("../cljs/spec/alpha.js", ['cljs.spec.alpha'], ['cljs.core', 'goog.object', 'clojure.string', 'clojure.walk', 'cljs.spec.gen.alpha']);
goog.addDependency("../cljs/core$macros.js", ['cljs.core$macros'], ['cljs.compiler', 'cljs.core', 'cljs.env', 'clojure.set', 'cljs.analyzer', 'clojure.string', 'clojure.walk']);
goog.addDependency("../cljs/js.js", ['cljs.js'], ['cljs.compiler', 'cljs.tools.reader', 'cljs.core', 'goog.crypt.base64', 'cljs.tools.reader.reader_types', 'cljs.env', 'goog.string.StringBuffer', 'cljs.tagged_literals', 'cljs.analyzer', 'cljs.source_map', 'clojure.string', 'cljs.spec.alpha', 'clojure.walk', 'cljs.core$macros']);
goog.addDependency("../orcl/naive/vars.js", ['orcl.naive.vars'], ['cljs.core']);
goog.addDependency("../orcl/naive/impl.js", ['orcl.naive.impl'], ['orcl.utils', 'cljs.core', 'orcl.naive.vars']);
goog.addDependency("../orcl/naive/lib.js", ['orcl.naive.lib'], ['cljs.core', 'orcl.naive.impl', 'orcl.naive.vars']);
goog.addDependency("../orcl/naive.js", ['orcl.naive'], ['orcl.utils', 'cljs.js', 'cljs.core', 'orcl.naive.impl', 'orcl.naive.lib', 'orcl.naive.vars']);
goog.addDependency("../cljs/core/async/impl/protocols.js", ['cljs.core.async.impl.protocols'], ['cljs.core']);
goog.addDependency("../cljs/core/async/impl/buffers.js", ['cljs.core.async.impl.buffers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/dispatch.js", ['cljs.core.async.impl.dispatch'], ['cljs.core', 'cljs.core.async.impl.buffers', 'goog.async.nextTick']);
goog.addDependency("../cljs/core/async/impl/channels.js", ['cljs.core.async.impl.channels'], ['cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/ioc_helpers.js", ['cljs.core.async.impl.ioc_helpers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/timers.js", ['cljs.core.async.impl.timers'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async.js", ['cljs.core.async'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols', 'cljs.core.async.impl.ioc_helpers', 'cljs.core.async.impl.timers']);
goog.addDependency("../cljs/pprint.js", ['cljs.pprint'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../figwheel/client/utils.js", ['figwheel.client.utils'], ['goog.userAgent.product', 'goog.string', 'cljs.core', 'goog.object', 'goog.string.StringBuffer', 'cljs.pprint', 'goog.async.Deferred', 'clojure.string', 'cljs.reader']);
goog.addDependency("../figwheel/client/file_reloading.js", ['figwheel.client.file_reloading'], ['goog.string', 'goog.net.jsloader', 'goog.Uri', 'cljs.core', 'goog.object', 'cljs.core.async', 'clojure.set', 'goog.html.legacyconversions', 'figwheel.client.utils', 'goog.async.Deferred', 'clojure.string']);
goog.addDependency("../cljs/repl.js", ['cljs.repl'], ['cljs.core', 'cljs.spec.alpha']);
goog.addDependency("../figwheel/client/socket.js", ['figwheel.client.socket'], ['cljs.core', 'goog.object', 'figwheel.client.utils', 'cljs.reader']);
goog.addDependency("../figwheel/client/heads_up.js", ['figwheel.client.heads_up'], ['goog.dom', 'goog.string', 'cljs.core', 'goog.dom.dataset', 'goog.object', 'cljs.core.async', 'cljs.pprint', 'figwheel.client.utils', 'figwheel.client.socket', 'clojure.string']);
goog.addDependency("../figwheel/client.js", ['figwheel.client'], ['goog.userAgent.product', 'goog.Uri', 'cljs.core', 'goog.object', 'cljs.core.async', 'figwheel.client.file_reloading', 'figwheel.client.utils', 'cljs.repl', 'figwheel.client.heads_up', 'figwheel.client.socket', 'clojure.string', 'cljs.reader']);
goog.addDependency("../figwheel/connect/build_dev.js", ['figwheel.connect.build_dev'], ['orcl.naive', 'cljs.core', 'figwheel.client', 'figwheel.client.utils']);
goog.addDependency("../process/env.js", ['process.env'], ['cljs.core']);
goog.addDependency("../blancas/kern/i18n.js", ['blancas.kern.i18n'], ['cljs.core']);
goog.addDependency("../blancas/kern/char.js", ['blancas.kern.char$'], ['cljs.core', 'clojure.string']);
goog.addDependency("../blancas/kern/core.js", ['blancas.kern.core'], ['cljs.core', 'blancas.kern.i18n', 'cljs.pprint', 'blancas.kern.char$', 'clojure.string']);
goog.addDependency("../blancas/kern/lexer.js", ['blancas.kern.lexer'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.i18n', 'clojure.string']);
goog.addDependency("../orcl/lexer.js", ['orcl.lexer'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.i18n', 'blancas.kern.lexer']);
goog.addDependency("../blancas/kern/lexer/c_style.js", ['blancas.kern.lexer.c_style'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.lexer']);
goog.addDependency("../blancas/kern/expr.js", ['blancas.kern.expr'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.lexer.c_style', 'blancas.kern.i18n']);
goog.addDependency("../orcl/parser/utils.js", ['orcl.parser.utils'], ['blancas.kern.core', 'orcl.lexer', 'cljs.core', 'blancas.kern.expr']);
goog.addDependency("../cljs/test.js", ['cljs.test'], ['cljs.core', 'cljs.pprint', 'clojure.string']);
goog.addDependency("../orcl/parser.js", ['orcl.parser'], ['blancas.kern.core', 'orcl.utils', 'orcl.lexer', 'cljs.core', 'blancas.kern.expr', 'cljs.pprint', 'orcl.parser.utils']);
goog.addDependency("../orcl/utils/cursor.js", ['orcl.utils.cursor'], ['cljs.core']);
goog.addDependency("../orcl/analyzer/vars.js", ['orcl.analyzer.vars'], ['cljs.core']);
goog.addDependency("../orcl/analyzer/patterns.js", ['orcl.analyzer.patterns'], ['orcl.utils', 'cljs.core']);
goog.addDependency("../orcl/analyzer.js", ['orcl.analyzer'], ['orcl.utils', 'orcl.utils.cursor', 'cljs.core', 'clojure.set', 'orcl.analyzer.vars', 'orcl.analyzer.patterns']);
goog.addDependency("../orcl/naive/functional_test.js", ['orcl.naive.functional_test'], ['orcl.naive', 'orcl.parser', 'cljs.core', 'cljs.test', 'orcl.naive.lib', 'orcl.analyzer', 'orcl.naive.vars']);

==> backend-naive-0.1.0-20170829.144415-7.jar: public/js/out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.math.Integer', 'goog.string.StringBuffer', 'goog.array', 'goog.math.Long']);
goog.addDependency("../orcl/utils/hashify.js", ['orcl.utils.hashify'], ['cljs.core']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../orcl/utils.js", ['orcl.utils'], ['orcl.utils.hashify', 'cljs.core', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/impl/utils.js", ['cljs.tools.reader.impl.utils'], ['goog.string', 'cljs.core', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/reader_types.js", ['cljs.tools.reader.reader_types'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/tools/reader/impl/inspect.js", ['cljs.tools.reader.impl.inspect'], ['cljs.core']);
goog.addDependency("../cljs/tools/reader/impl/errors.js", ['cljs.tools.reader.impl.errors'], ['cljs.core', 'cljs.tools.reader.reader_types', 'cljs.tools.reader.impl.inspect', 'clojure.string']);
goog.addDependency("../cljs/tools/reader/impl/commons.js", ['cljs.tools.reader.impl.commons'], ['cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/tools/reader.js", ['cljs.tools.reader'], ['cljs.tools.reader.impl.commons', 'goog.string', 'cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils', 'goog.array']);
goog.addDependency("../cljs/env.js", ['cljs.env'], ['cljs.core']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../cljs/tools/reader/edn.js", ['cljs.tools.reader.edn'], ['cljs.tools.reader.impl.commons', 'cljs.tools.reader', 'goog.string', 'cljs.tools.reader.impl.errors', 'cljs.core', 'cljs.tools.reader.reader_types', 'goog.string.StringBuffer', 'cljs.tools.reader.impl.utils']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['cljs.tools.reader.edn', 'cljs.tools.reader', 'cljs.core', 'goog.object', 'goog.string.StringBuffer']);
goog.addDependency("../cljs/tagged_literals.js", ['cljs.tagged_literals'], ['cljs.core', 'cljs.reader']);
goog.addDependency("../cljs/analyzer.js", ['cljs.analyzer'], ['cljs.tools.reader', 'goog.string', 'cljs.core', 'cljs.tools.reader.reader_types', 'cljs.env', 'clojure.set', 'cljs.tagged_literals', 'clojure.string', 'cljs.reader']);
goog.addDependency("../cljs/source_map/base64.js", ['cljs.source_map.base64'], ['cljs.core']);
goog.addDependency("../cljs/source_map/base64_vlq.js", ['cljs.source_map.base64_vlq'], ['cljs.source_map.base64', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../cljs/source_map.js", ['cljs.source_map'], ['cljs.source_map.base64_vlq', 'cljs.core', 'goog.object', 'clojure.set', 'clojure.string']);
goog.addDependency("../cljs/compiler.js", ['cljs.compiler'], ['cljs.tools.reader', 'goog.string', 'cljs.core', 'cljs.env', 'goog.string.StringBuffer', 'clojure.set', 'cljs.analyzer', 'cljs.source_map', 'clojure.string']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../cljs/spec/gen/alpha.js", ['cljs.spec.gen.alpha'], ['cljs.core']);
goog.addDependency("../cljs/spec/alpha.js", ['cljs.spec.alpha'], ['cljs.core', 'goog.object', 'clojure.string', 'clojure.walk', 'cljs.spec.gen.alpha']);
goog.addDependency("../cljs/core$macros.js", ['cljs.core$macros'], ['cljs.compiler', 'cljs.core', 'cljs.env', 'clojure.set', 'cljs.analyzer', 'clojure.string', 'clojure.walk']);
goog.addDependency("../cljs/js.js", ['cljs.js'], ['cljs.compiler', 'cljs.tools.reader', 'cljs.core', 'goog.crypt.base64', 'cljs.tools.reader.reader_types', 'cljs.env', 'goog.string.StringBuffer', 'cljs.tagged_literals', 'cljs.analyzer', 'cljs.source_map', 'clojure.string', 'cljs.spec.alpha', 'clojure.walk', 'cljs.core$macros']);
goog.addDependency("../orcl/naive/vars.js", ['orcl.naive.vars'], ['cljs.core']);
goog.addDependency("../orcl/naive/impl.js", ['orcl.naive.impl'], ['orcl.utils', 'cljs.core', 'orcl.naive.vars']);
goog.addDependency("../orcl/naive/lib.js", ['orcl.naive.lib'], ['cljs.core', 'orcl.naive.impl', 'orcl.naive.vars']);
goog.addDependency("../orcl/naive.js", ['orcl.naive'], ['orcl.utils', 'cljs.js', 'cljs.core', 'orcl.naive.impl', 'orcl.naive.lib', 'orcl.naive.vars']);
goog.addDependency("../orcl/testkit/proto.js", ['orcl.testkit.proto'], ['cljs.core']);
goog.addDependency("../orcl/naive/tests_runner.js", ['orcl.naive.tests_runner'], ['orcl.naive', 'cljs.core', 'orcl.testkit.proto', 'orcl.naive.lib']);
goog.addDependency("../process/env.js", ['process.env'], ['cljs.core']);
goog.addDependency("../cljs/core/async/impl/protocols.js", ['cljs.core.async.impl.protocols'], ['cljs.core']);
goog.addDependency("../cljs/core/async/impl/ioc_helpers.js", ['cljs.core.async.impl.ioc_helpers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../blancas/kern/i18n.js", ['blancas.kern.i18n'], ['cljs.core']);
goog.addDependency("../cljs/pprint.js", ['cljs.pprint'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer', 'clojure.string']);
goog.addDependency("../blancas/kern/char.js", ['blancas.kern.char$'], ['cljs.core', 'clojure.string']);
goog.addDependency("../blancas/kern/core.js", ['blancas.kern.core'], ['cljs.core', 'blancas.kern.i18n', 'cljs.pprint', 'blancas.kern.char$', 'clojure.string']);
goog.addDependency("../blancas/kern/lexer.js", ['blancas.kern.lexer'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.i18n', 'clojure.string']);
goog.addDependency("../orcl/lexer.js", ['orcl.lexer'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.i18n', 'blancas.kern.lexer']);
goog.addDependency("../blancas/kern/lexer/c_style.js", ['blancas.kern.lexer.c_style'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.lexer']);
goog.addDependency("../blancas/kern/expr.js", ['blancas.kern.expr'], ['blancas.kern.core', 'cljs.core', 'blancas.kern.lexer.c_style', 'blancas.kern.i18n']);
goog.addDependency("../orcl/parser/utils.js", ['orcl.parser.utils'], ['blancas.kern.core', 'orcl.lexer', 'cljs.core', 'blancas.kern.expr']);
goog.addDependency("../cljs/test.js", ['cljs.test'], ['cljs.core', 'cljs.pprint', 'clojure.string']);
goog.addDependency("../cljs/core/async/impl/buffers.js", ['cljs.core.async.impl.buffers'], ['cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async/impl/dispatch.js", ['cljs.core.async.impl.dispatch'], ['cljs.core', 'cljs.core.async.impl.buffers', 'goog.async.nextTick']);
goog.addDependency("../cljs/core/async/impl/channels.js", ['cljs.core.async.impl.channels'], ['cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols']);
goog.addDependency("../figwheel/client/utils.js", ['figwheel.client.utils'], ['goog.userAgent.product', 'goog.string', 'cljs.core', 'goog.object', 'goog.string.StringBuffer', 'cljs.pprint', 'goog.async.Deferred', 'clojure.string', 'cljs.reader']);
goog.addDependency("../figwheel/client/socket.js", ['figwheel.client.socket'], ['cljs.core', 'goog.object', 'figwheel.client.utils', 'cljs.reader']);
goog.addDependency("../cljs/core/async/impl/timers.js", ['cljs.core.async.impl.timers'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.protocols']);
goog.addDependency("../cljs/core/async.js", ['cljs.core.async'], ['cljs.core.async.impl.channels', 'cljs.core.async.impl.dispatch', 'cljs.core', 'cljs.core.async.impl.buffers', 'cljs.core.async.impl.protocols', 'cljs.core.async.impl.ioc_helpers', 'cljs.core.async.impl.timers']);
goog.addDependency("../figwheel/client/file_reloading.js", ['figwheel.client.file_reloading'], ['goog.string', 'goog.net.jsloader', 'goog.Uri', 'cljs.core', 'goog.object', 'cljs.core.async', 'clojure.set', 'goog.html.legacyconversions', 'figwheel.client.utils', 'goog.async.Deferred', 'clojure.string']);
goog.addDependency("../orcl/parser.js", ['orcl.parser'], ['blancas.kern.core', 'orcl.utils', 'orcl.lexer', 'cljs.core', 'blancas.kern.expr', 'cljs.pprint', 'orcl.parser.utils']);
goog.addDependency("../orcl/utils/cursor.js", ['orcl.utils.cursor'], ['cljs.core']);
goog.addDependency("../orcl/analyzer/vars.js", ['orcl.analyzer.vars'], ['cljs.core']);
goog.addDependency("../orcl/analyzer/patterns.js", ['orcl.analyzer.patterns'], ['orcl.utils', 'cljs.core']);
goog.addDependency("../orcl/analyzer.js", ['orcl.analyzer'], ['orcl.utils', 'orcl.utils.cursor', 'cljs.core', 'clojure.set', 'orcl.analyzer.vars', 'orcl.analyzer.patterns']);
goog.addDependency("../orcl/naive/functional_test.js", ['orcl.naive.functional_test'], ['orcl.naive', 'orcl.parser', 'cljs.core', 'cljs.test', 'orcl.naive.lib', 'orcl.analyzer', 'orcl.naive.vars']);
goog.addDependency("../cljs/repl.js", ['cljs.repl'], ['cljs.core', 'cljs.spec.alpha']);
goog.addDependency("../figwheel/client/heads_up.js", ['figwheel.client.heads_up'], ['goog.dom', 'goog.string', 'cljs.core', 'goog.dom.dataset', 'goog.object', 'cljs.core.async', 'cljs.pprint', 'figwheel.client.utils', 'figwheel.client.socket', 'clojure.string']);
goog.addDependency("../figwheel/client.js", ['figwheel.client'], ['goog.userAgent.product', 'goog.Uri', 'cljs.core', 'goog.object', 'cljs.core.async', 'figwheel.client.file_reloading', 'figwheel.client.utils', 'cljs.repl', 'figwheel.client.heads_up', 'figwheel.client.socket', 'clojure.string', 'cljs.reader']);
goog.addDependency("../figwheel/connect/build_dev.js", ['figwheel.connect.build_dev'], ['orcl.naive', 'cljs.core', 'figwheel.client', 'figwheel.client.utils']);
